_antonyms = {
    "gebėjimas": "nesugebėjimas",
    "nenormalus": "normalus",
    "panaikinti": "nustatyti",
    "nebuvimas": "buvimas",
    "nėra": "egzistuoja",
    "ateitis": "praeitis",
    "absoliutus": "santykinis",
    "susilaikyti": "veikti",
    "abstraktus": "betonas",
    "gausa": "trūkumas",
    "gausu": "trūksta",
    "priimti": "atmesti",
    "pripažinti": "paneigti",
    "priimtinas": "nepertraukiamas",
    "priėmimas": "atmetimas",
    "prieinama": "neprieinama",
    "tiksliai": "netikslus",
    "pripažintas": "nepripažintas",
    "pažintis": "svetimas",
    "veikti": "susilaikyti",
    "veiksmas": "neveikimas",
    "aktyvus": "tylus",
    "išlikę": "išnykęs",
    "triukšmingas": "tylus",
    "veikla": "neveiklumas",
    "faktinis": "potencialus",
    "papildyti": "atimti",
    "papildomai": "atimtis",
    "tinkamas": "netinkamas",
    "būdvardis": "esminis",
    "suaugęs": "nepilnametis",
    "iš anksto": "pasitraukti",
    "priekyje": "galas",
    "veer": "atgal",
    "pranašumas": "nepilnavertiškumas",
    "patvirtinimas": "nepatvirtinimas",
    "teigiamas": "neigiamas",
    "neutralus": "neigiamas",
    "aft": "fore",
    "amžius": "atgaivinti",
    "amžiaus": "jaunas",
    "agitacija": "ramybė",
    "sutinku": "nesutikti",
    "malonus": "nemalonus",
    "susitarimas": "nesutarimas",
    "pakeista": "nepakitęs",
    "alternatyva": "priešingas",
    "mėgėjas": "profesionalus",
    "dviprasmiškas": "nedviprasmiškas",
    "draugiškas": "nedraugiškas",
    "amfibijas": "antžeminis",
    "analinis": "žodžiu",
    "analogiškas": "homologiškas",
    "analizė": "sintezė",
    "analitinis": "sintetinis",
    "protėvis": "palikuonis",
    "kampinis": "suapvalintas",
    "gyvinti": "negyvas",
    "atsakyti": "klausimas",
    "antagonistinis": "sinergetinis",
    "antecedentas": "vėlesnis",
    "priekinis": "posterior",
    "antiseptikas": "septinis",
    "išvaizda": "išnykimas",
    "dėkingi": "nusidėvėjimas",
    "patvirtinti": "nepatvirtinkite",
    "vandens": "amfibijas",
    "antžeminis": "amfibijas",
    "vandeninis": "tigras",
    "ranka": "atrakinti",
    "ginkluotosios": "neginklu",
    "atvykti": "palikti",
    "pakilti": "nustatyti",
    "pakilimas": "nusileidimas",
    "miega": "pabusti",
    "pritarimas": "nepasitenkinimas",
    "asimetrija": "simetrija",
    "ateizmas": "teizmas",
    "pritvirtinti": "atsitraukti",
    "ataka": "ginti",
    "baudžiamasis persekiojimas": "gynyba",
    "dėmesio": "neatsargumas",
    "pritraukimas": "atbaidymas",
    "girdimas": "neskausmingas",
    "padidinimas": "mažėjimas",
    "teta": "dėdė",
    "įgaliotas": "neleistinas",
    "automatinis": "vadovas",
    "vengti": "priešintis",
    "pabusti": "miegoti",
    "atgal": "persiųsti",
    "pasitraukti": "indėlis",
    "galas": "galva",
    "fonas": "priekinio plano",
    "atvirkštinis": "aversas",
    "blogai": "gerai",
    "velnias": "gerai",
    "blogybė": "gerumas",
    "subalansuotas": "nesubalansuotas",
    "turėti": "buliukas",
    "grazus": "negraži",
    "grožis": "bjaurumas",
    "prasideda": "galas",
    "pradžia": "viduryje",
    "anksti": "vėlai",
    "tikėjimas": "netikėjimas",
    "sulenkti": "ištiesinti",
    "gerybingas": "piktybinis",
    "didelis": "mažas",
    "gimdymas": "mirtis",
    "biseksualus": "homoseksualas",
    "juoda": "balta",
    "palaiminti": "prakeiksmas",
    "palaimintas": "prakeiktas",
    "beverčiai": "vertingas",
    "kruvinas": "beverčiai",
    "blur": "sutelkti dėmesį",
    "virti": "užšaldyti",
    "drąsus": "bjaurus",
    "drąsa": "bailumas",
    "skolintis": "skolinti",
    "skolininkas": "kreditorius",
    "apačioje": "viršuje",
    "privaloma": "nesusijusi",
    "berniukas": "mergaitė",
    "boikotuoti": "globoja",
    "pertrauka": "remontas",
    "purus": "nepažeistas",
    "ryškesni": "tamsinti",
    "apšviesti": "tamsinti",
    "sunaikintas": "nepažeistas",
    "brolis": "sesuo",
    "buliukas": "turėti",
    "užsiėmes": "tuščiąja eiga",
    "darbas": "tuščiąja eiga",
    "pirkti": "parduoti",
    "ramus": "audringas",
    "ramybė": "karas",
    "galingas": "bejėgis",
    "pajėgumas": "nedarbingumas",
    "pinigai": "kreditas",
    "debetas": "kreditas",
    "centras": "kairėje",
    "cerebralinis": "emocinis",
    "tikrumas": "netikrumas",
    "keisti": "likti",
    "išvykti": "likti",
    "judėti": "likti",
    "kintamas": "nepakeičiama",
    "pasikeitė": "nepakeistas",
    "mokestis": "išleidimas",
    "įsitraukti": "išleidimas",
    "pigus": "brangus",
    "nudžiuginti": "skųstis",
    "linksmas": "depresija",
    "vaikas": "tėvas",
    "civilinis": "kariuomenė",
    "pretenzija": "prarasti",
    "aiškumas": "neskaidrumas",
    "pagarba": "nepagarba",
    "skaidrumas": "neskaidrumas",
    "švarus": "nešvarus",
    "dvasininkai": "pasaulis",
    "dvasininkas": "nesąmonė",
    "uždaryti": "atviras",
    "uždaryta": "atviras",
    "artimas": "atvirumas",
    "pakrantės": "vidaus vandenyse",
    "nuoseklus": "nesuderintas",
    "šalta": "karštas",
    "užstatas": "lineal",
    "komedija": "tragedija",
    "komfortas": "diskomfortas",
    "bendras": "nedažni",
    "suderinama": "nesuderinama",
    "kompetencija": "nekompetencija",
    "kompetentingas": "nekompetentingas",
    "varzybos": "bendradarbiavimas",
    "skųstis": "nudžiuginti",
    "išsamumas": "neišsamumas",
    "kompleksas": "paprasta",
    "junginys": "paprasta",
    "atitinka reikalavimus": "iššaukiantis",
    "komplikuoja": "supaprastinti",
    "įgaubtas": "išgaubtas",
    "įsivaizduoti": "nuolankumas",
    "pasididžiavimas": "nuolankumas",
    "koncentracija": "platinimas",
    "koncentrinis": "ekscentriškas",
    "koncepcija": "klaidingas supratimas",
    "susijusi": "nesvarbu",
    "betonas": "abstraktus",
    "patvirtintas": "nepatvirtintas",
    "priešintis": "vengti",
    "jungianti": "disjunctive",
    "prisijungti": "atjunkite",
    "prijungtas": "nesusijusi",
    "sąmonė": "sąmonės netekimas",
    "konservatyvus": "liberalus",
    "konservuoti": "atliekos",
    "dėmesingas": "nesvarbu",
    "nuoseklumas": "nenuoseklumas",
    "konsonantas": "balsis",
    "pastebimas": "nepastebimas",
    "konstitucinis": "nekonstitucinis",
    "vartoti": "susilaikyti",
    "turinys": "nepasitenkinimas",
    "nuolatinis": "nepertraukiamas",
    "tęstinumas": "nutraukimas",
    "tęsti": "nutraukti",
    "sutartis": "išsiplėtė",
    "susitraukimas": "plėtra",
    "patogus": "nepatogu",
    "sutartinis": "netradicinis",
    "suvienyti": "padalinti",
    "konvergencija": "skirtumas",
    "konvergenti": "skiriasi",
    "išgaubtas": "įgaubtas",
    "įsitikinęs": "nenuosekli",
    "saunus": "šiluma",
    "bendradarbiavimas": "varzybos",
    "kosmopolitinis": "provincijos",
    "drąsos": "bailys",
    "padengti": "atskleisti",
    "slaptas": "atvira",
    "bailys": "drąsos",
    "kreditas": "debetas",
    "kreditorius": "skolininkas",
    "kritikuoti": "pagirti",
    "verkis": "juoktis",
    "išgydomas": "neišgydomas",
    "prakeiksmas": "palaiminti",
    "prakeiktas": "palaimintas",
    "išlenktas": "tiesiai",
    "supjaustyti": "nesupjaustytas",
    "pavojus": "saugumas",
    "pavojingas": "saugus",
    "tamsi": "šviesa",
    "tamsinti": "apšviesti",
    "tamsa": "lengvumas",
    "sunkumas": "lengvumas",
    "dukra": "sūnus",
    "diena": "naktis",
    "kurtis": "klausymasis",
    "mirtis": "gimdymas",
    "padorumas": "nepadorumas",
    "padorus": "nepadorus",
    "lapuočių": "visada žalia",
    "sprendimas": "nelygybė",
    "lemiamas": "neryžtingas",
    "nuosmukis": "tobulinimas",
    "mažinti": "padidinti",
    "sumažėjo": "padidėjo",
    "sumažėjimas": "prieaugis",
    "nugalėti": "pergalė",
    "ginti": "baudžiamasis persekiojimas",
    "atsakovas": "ieškovas",
    "gynyba": "baudžiamasis persekiojimas",
    "gynybinis": "agresyvus",
    "iššaukiantis": "atitinka reikalavimus",
    "trūkumas": "gausa",
    "apibrėžta": "neapibrėžtas",
    "defliacija": "infliacija",
    "delsimas": "skubėti",
    "laikytis": "skubėti",
    "paklausa": "tiekimas",
    "paneigti": "įrodyti",
    "atmesti": "kaukė",
    "priklausomas": "nepriklausomas",
    "indėlis": "pasitraukti",
    "nusidėvėjimas": "dėkingi",
    "depresija": "linksmas",
    "nusileisti": "pakilti",
    "palikuonis": "protėvis",
    "nusileidimas": "pakilimas",
    "apibūdinantis": "norminis",
    "pageidautina": "nepageidautinas",
    "neviltis": "tikiuosi",
    "beviltiška": "viltis",
    "sunaikinta": "konservuota",
    "atsitraukti": "pritvirtinti",
    "devoliucija": "evoliucija",
    "skirtis": "suvienyti",
    "nevienodas": "lygus",
    "skirtumas": "konvergencija",
    "sunku": "lengvumas",
    "neramus": "lengva",
    "kruopštus": "nesąžiningi",
    "skiedimas": "koncentracija",
    "platinimas": "koncentracija",
    "mažėjimas": "padidinimas",
    "purvinas": "švarus",
    "nešvarus": "švarus",
    "išjungti": "įgalinti",
    "nesutikti": "sutinku",
    "nepatogu": "pikantiškas",
    "nesutarimas": "susitarimas",
    "išnykimas": "išvaizda",
    "nepatvirtinimas": "patvirtinimas",
    "nepatvirtinkite": "patvirtinti",
    "atrakinti": "užraktas",
    "išleidimas": "įsitraukti",
    "atsisakyti": "priimti",
    "prarasti": "rasti",
    "diskomfortas": "komfortas",
    "atjunkite": "prisijungti",
    "nepasitenkinimas": "pritarimas",
    "nutraukimas": "tęstinumas",
    "nutraukti": "tęsti",
    "nepertraukiamas": "priimtinas",
    "atgrasinkite": "paskatinti",
    "nusivylimas": "skatinimas",
    "atleiskite": "užsiimti",
    "nesąžiningas": "nuoširdus",
    "nesąžiningumas": "sąžiningumas",
    "nesąžiningi": "kruopštus",
    "dezinfekuoti": "užkrėsti",
    "suskaidyti": "integruoti",
    "disjunctive": "jungianti",
    "nepatinka": "malonu",
    "išstumti": "pateikia",
    "nepaklusnumas": "paklusnumas",
    "nepaklusnus": "paklusnus",
    "nepaklusti": "paklusk",
    "sutrikimas": "įsakymas",
    "netvarkingai": "tvarkingai",
    "neorganizuotas": "organizuotas",
    "diskvalifikuoti": "kvalifikuoti",
    "nepriimtinas": "priimtinas",
    "nuversti": "reputacija",
    "nepagarba": "pagarba",
    "nepagarbus": "dėkingas",
    "kantrumas": "paslauga",
    "skirtingas": "panašus",
    "disonansas": "harmonija",
    "atgrasyti": "įtikinti",
    "distalinis": "proksimalinis",
    "toli": "uždaryti",
    "atviras": "uždaryti",
    "skiriasi": "konvergenti",
    "nepasitikėjimas": "pasitikėjimas",
    "dieną": "naktinis",
    "padalinti": "suvienyti",
    "atskirai": "bendras",
    "padalintas": "united",
    "dalijamasi": "nedalomas",
    "vidaus": "užsienio",
    "gimtoji": "užsienio",
    "dominuojantis": "pavaldus",
    "neveikiantis": "aktyvus",
    "išnykęs": "išlikę",
    "neaktyvus": "aktyvus",
    "pasyvus": "aktyvus",
    "tylus": "triukšmingas",
    "dvigubai": "vienišas",
    "daugkartinis": "vienišas",
    "balandis": "vanas",
    "dramatiškas": "lyrika",
    "sausas": "drėgnas",
    "rūgštus": "saldinti",
    "dėl to": "nepagrįstas",
    "nuobodus": "aštrinti",
    "suplakti": "aštrinti",
    "mirti": "kylantis",
    "žemiškas": "dangus",
    "lengvumas": "sunkumas",
    "lengva": "neramus",
    "atsipalaiduoti": "vėjas",
    "ekscentriškas": "koncentrinis",
    "išsilavinę": "nebaigtas",
    "efektyvus": "neefektyvus",
    "efektyvumas": "neveiksmingumas",
    "išvažiavimas": "patekimas",
    "elastinga": "neelastinis",
    "emocinis": "cerebralinis",
    "empirinis": "teorinis",
    "tuštuma": "pilnatvė",
    "tuščia": "pilnas",
    "plonas": "susitraukti",
    "įgalinti": "išjungti",
    "paskatinti": "atgrasinkite",
    "skatinimas": "nusivylimas",
    "pabaiga": "pradžia",
    "viduryje": "anksti",
    "endemiškas": "kosmopolitinis",
    "provincijos": "kosmopolitinis",
    "energingas": "mieguistas",
    "vykdomas": "atleidžiamas nuo mokesčio",
    "užsiimti": "atleiskite",
    "mėgautis": "kenčia",
    "įveskite": "išeiti",
    "lygus": "nevienodas",
    "lygybė": "nelygybė",
    "ekvatorinis": "poliarinis",
    "teisingas": "neteisinga",
    "ištrinti": "įrašyti",
    "nustatyti": "pakilti",
    "turtingas": "nepastebimas",
    "visada žalia": "lapuočių",
    "evoliucija": "devoliucija",
    "išskyrimas": "įtraukimas",
    "atleidžiamas nuo mokesčio": "vykdomas",
    "iškvėpti": "įkvėpti",
    "egzistuoja": "nėra",
    "išeiti": "įveskite",
    "išplėsti": "siaura",
    "išsiplėtė": "sutartis",
    "plėtra": "susitraukimas",
    "tikimasi": "netikėtas",
    "brangus": "pigus",
    "patyręs": "nepatyręs",
    "eksportuoti": "importas",
    "išreikšti": "vietinis",
    "apskritai": "konkretus",
    "nacionalinis": "tarptautinis",
    "pratęsimas": "lenkimas",
    "eksterjeras": "interjeras",
    "išorinis": "būdingas",
    "išoriškai": "viduje",
    "gesinti": "užsiliepsnoti",
    "neakivaizdinis": "intramural",
    "nepaprastas": "paprastas",
    "nesėkmingai": "praeiti",
    "bėgimas": "stovintis",
    "nesėkmė": "sėkmė",
    "šviesus": "nesąžininga",
    "ištikimas": "netikri",
    "kritimo": "pakilti",
    "klaidingas": "neklystantis",
    "kritimas": "kyla",
    "melas": "stovėti",
    "neteisingumas": "tiesa",
    "šlovė": "skriaudimas",
    "pažįstamas": "nepažįstamas",
    "išgalvotas": "paprastas",
    "riebalai": "plonas",
    "pilnas": "tuščia",
    "storas": "plonas",
    "susitraukti": "ruožas",
    "tėvas": "vaikas",
    "fauna": "flora",
    "palankus": "nepalankus",
    "federalinė": "vienarūšis",
    "moteris": "patinas",
    "moteriškas": "neuter",
    "moteriškumas": "vyriškumas",
    "derlingas": "sterilus",
    "ištikimybė": "netikėjimas",
    "figūra": "žemė",
    "užpildyti": "tuščia",
    "rasti": "prarasti",
    "baigti": "pradėti",
    "sustabdyti": "pradėti",
    "baigtinis": "begalinis",
    "ugnis": "samdyti",
    "lenkimas": "pratęsimas",
    "plūdė": "nuskristi",
    "šaltinis": "nuskristi",
    "flora": "fauna",
    "sutelkti dėmesį": "blur",
    "priešas": "draugas",
    "kartus": "atsiskleisti",
    "sekite": "prieš tai",
    "pasisekė": "prieš tai",
    "pasekėjas": "lyderis",
    "kvailystė": "išmintis",
    "kvaila": "protingas",
    "pėdos": "galva",
    "uodega": "galva",
    "uždrausti": "leidimas",
    "fore": "aft",
    "priekinio plano": "fonas",
    "užsienio": "gimtoji",
    "pamiršk": "prisiminti",
    "atleiskis": "nepagarbus",
    "formalizmas": "imitacija",
    "laimingas": "nelaimingas",
    "persiųsti": "atvirkštinis",
    "aversas": "atvirkštinis",
    "negerai": "šviesus",
    "nesąžininga": "šviesus",
    "rasta": "prarastas",
    "broliškas": "identiškas",
    "užšaldyti": "virti",
    "dažnai": "retai",
    "draugas": "priešas",
    "galva": "uodega",
    "pilnatvė": "tuštuma",
    "funkcinis": "ekologiškas",
    "neorganinis": "ekologiškas",
    "pelnas": "nuostolis",
    "dujinis": "tvirtas",
    "tuščiaviduris": "tvirtas",
    "rinkti": "skleisti",
    "bendrumas": "ypatumas",
    "turtinga": "švelnus",
    "mergaitė": "berniukas",
    "gerai": "velnias",
    "gerumas": "blogybė",
    "palaipsniui": "staiga",
    "dėkingas": "nepagarbus",
    "didesnis": "mažesnis",
    "žalias": "prinokę",
    "bruto": "neto",
    "žemė": "figūra",
    "kaltumas": "nekaltumas",
    "kaltas": "nekaltas",
    "laimingai": "deja",
    "laimė": "nelaimė",
    "kietumas": "minkštumas",
    "garsumas": "minkštumas",
    "ryškumas": "minkštumas",
    "harmonija": "disonansas",
    "nekenčiu": "meilė",
    "žiaurus": "patraukli",
    "vanas": "balandis",
    "sveikas": "nesveika",
    "klausymasis": "kurtis",
    "šiluma": "saunus",
    "dangus": "žemiškas",
    "nevienalytiškumas": "vienalytiškumas",
    "paslėpti": "rodyti",
    "samdyti": "ugnis",
    "nukentėti": "praleisti",
    "šventas": "apgaulingas",
    "vienalytiškumas": "nevienalytiškumas",
    "homologiškas": "analogiškas",
    "homoseksualas": "biseksualus",
    "nuoširdus": "nesąžiningas",
    "sąžiningumas": "nesąžiningumas",
    "garbė": "nesąžiningi",
    "tikiuosi": "beviltiška",
    "viltis": "beviltiška",
    "horizontalus": "vertikalus",
    "priešiškas": "draugiškas",
    "nedraugiškas": "draugiškas",
    "karštas": "šalta",
    "kuklus": "didžiuojasi",
    "nuolankumas": "pasididžiavimas",
    "alkanas": "ištroškęs",
    "identiškas": "broliškas",
    "tuščiąja eiga": "darbas",
    "tigras": "vandeninis",
    "užsiliepsnoti": "gesinti",
    "ignoruoti": "pastebėti",
    "neteisėtas": "teisėtas",
    "neteisėtumas": "teisėtumas",
    "neįskaitomas": "įskaitomas",
    "nelogiška": "logiškas",
    "imitacija": "formalizmas",
    "nematerialus": "medžiaga",
    "nebrandumas": "terminas",
    "neišmatuojamas": "išmatuojami",
    "amoralus": "moralinis",
    "amoralumas": "moralė",
    "nemirtingas": "mirtingasis",
    "nemirtingumas": "mirtingumas",
    "nekintamas": "keičiamas",
    "nešališkumas": "dališkumas",
    "nekantrumas": "kantrybė",
    "nekantrus": "pacientas",
    "nepastebimas": "atsargiai",
    "netobulumas": "tobulumas",
    "nepralaidus": "pralaidus",
    "neleistinas": "įgaliotas",
    "be asmenybės": "asmeninis",
    "importas": "eksportuoti",
    "svarbu": "nesvarbus",
    "neįmanoma": "galimybė",
    "bejėgis": "galingas",
    "neįtikėtinas": "tikėtinas",
    "patobulintas": "nepagerintas",
    "tobulinimas": "nuosmukis",
    "neprotingas": "apdairus",
    "priemaiša": "grynumas",
    "nesugebėjimas": "gebėjimas",
    "neprieinama": "prieinama",
    "netikslus": "tiksliai",
    "neveikimas": "veiksmas",
    "neveiklumas": "veikla",
    "nepakankamas": "pakankamai",
    "negyvas": "gyvinti",
    "neatsargumas": "dėmesio",
    "neskausmingas": "girdimas",
    "nesugeba": "galingas",
    "nedarbingumas": "pajėgumas",
    "linkęs": "horizontalus",
    "vertikalus": "horizontalus",
    "įtraukimas": "išskyrimas",
    "nesuderintas": "nuoseklus",
    "nesuderinama": "suderinama",
    "nekompetencija": "kompetencija",
    "nekompetentingas": "kompetentingas",
    "neišsamumas": "išsamumas",
    "nesvarbu": "suinteresuotas",
    "nenuoseklumas": "nuoseklumas",
    "padidinti": "mažinti",
    "padidėjo": "sumažėjo",
    "prieaugis": "sumažėjimas",
    "neišgydomas": "išgydomas",
    "nepadorumas": "padorumas",
    "nepadorus": "padorus",
    "nelygybė": "lygybė",
    "neryžtingas": "lemiamas",
    "nepriklausomas": "priklausomas",
    "nesiskiria": "skiriasi",
    "nedalomas": "dalijamasi",
    "patalpose": "lauke",
    "neefektyvus": "efektyvus",
    "neveiksmingumas": "efektyvumas",
    "neelastinis": "elastinga",
    "netinkamas": "tinkamas",
    "neteisinga": "teisingumas",
    "nepatyręs": "patyręs",
    "neklystantis": "klaidingas",
    "skriaudimas": "šlovė",
    "užkrėsti": "dezinfekuoti",
    "prastesnė": "pranašesnis",
    "nepilnavertiškumas": "pranašumas",
    "netikėjimas": "tikėjimas",
    "begalinis": "baigtinis",
    "infliacija": "defliacija",
    "informuotas": "neinformuotas",
    "nedažni": "bendras",
    "retai": "dažnai",
    "patekimas": "išvažiavimas",
    "apgyvendintas": "negyvenamas",
    "įkvėpti": "iškvėpti",
    "vidaus vandenyse": "pakrantės",
    "nekaltumas": "kaltumas",
    "nekaltas": "kaltas",
    "nekenksmingas": "kenksmingas",
    "neveikia": "operatyvus",
    "psichiškas": "sane",
    "beprotybė": "sanity",
    "nesaugumas": "saugumas",
    "nereikšmingumas": "reikšmė",
    "nereikšmingas": "reikšmingas",
    "netirpi": "tirpus",
    "nemokumas": "mokumas",
    "nemokus": "tirpiklis",
    "nestabilumas": "stabilumas",
    "instrumental": "vokalas",
    "nepakankamumas": "pakankamumas",
    "nepakankamai": "pakankamai",
    "integruoti": "suskaidyti",
    "integracija": "atskyrimas",
    "žvalgyba": "kvailys",
    "suprantama": "nesuprantamas",
    "numatytas": "nenoras",
    "tyčia": "netyčia",
    "suinteresuotas": "nesvarbu",
    "įdomus": "neįdomu",
    "interjeras": "eksterjeras",
    "tarpinis": "terminalas",
    "vidinis": "išorinis",
    "viduje": "išoriškai",
    "tarptautinis": "nacionalinis",
    "vietinis": "apskritai",
    "netolerancija": "tolerancija",
    "netoleranti": "tolerantiškas",
    "nesuderinamas": "tractable",
    "intramural": "neakivaizdinis",
    "būdingas": "išorinis",
    "nematomas": "matomas",
    "neprivalomas": "savanoriškas",
    "neracionalus": "racionalus",
    "netaisyklingas": "reguliariai",
    "pažeidimas": "reguliarumas",
    "neatsakingas": "atsakingas",
    "klausimas": "atsakyti",
    "bendras": "atskirai",
    "džiaugsmas": "liūdesys",
    "džiaugsmingas": "liūdnas",
    "jaunesnysis": "vyresnysis",
    "teisingumas": "neteisinga",
    "nepilnametis": "pagrindinis",
    "kern": "kern",
    "karalius": "karalienė",
    "pasaulis": "dvasininkai",
    "vėlai": "anksti",
    "juoktis": "verkis",
    "teisėtas": "neteisėtas",
    "lax": "įtempta",
    "atsipalaidavęs": "įtempta",
    "nesąmonė": "dvasininkas",
    "vadovauti": "trūkumas",
    "lyderis": "pasekėjas",
    "palikti": "atvykti",
    "kairėje": "centras",
    "teisėtumas": "neteisėtumas",
    "legalizuoti": "neteisėta",
    "įskaitomas": "neįskaitomas",
    "skolinti": "skolintis",
    "skolintojas": "skolininkas",
    "pailginti": "sutrumpinti",
    "mažesnis": "pakelti",
    "mieguistas": "energingas",
    "lygis": "pakelti",
    "liberalus": "konservatyvus",
    "derlius": "stovėti",
    "šviesa": "tamsi",
    "patiko": "nepatinka",
    "ribotas": "neribotas",
    "lineal": "užstatas",
    "skystis": "dujinis",
    "tvirtas": "tuščiaviduris",
    "konkretus": "apskritai",
    "vieta": "studija",
    "užraktas": "atrakinti",
    "pateikia": "išstumti",
    "logiškas": "nelogiška",
    "ilgai": "trumpas",
    "aukštas": "trumpas",
    "atlaisvinti": "sustiprinti",
    "nuostolis": "pelnas",
    "prarastas": "rasta",
    "patraukli": "žiaurus",
    "meilė": "nekenčiu",
    "lyrika": "dramatiškas",
    "pagrindinis": "nepilnametis",
    "dauguma": "mažuma",
    "padaryti": "pertrauka",
    "remontas": "pertrauka",
    "patinas": "moteris",
    "kenksmingas": "nekenksmingas",
    "piktybinis": "gerybingas",
    "vadovas": "automatinis",
    "pažymėtas": "nepastebimas",
    "vedęs": "nevedęs",
    "vyriškas": "moteriškas",
    "neuter": "moteriškas",
    "vyriškumas": "moteriškumas",
    "kaukė": "atmesti",
    "medžiaga": "nematerialus",
    "motina": "tėvas",
    "terminas": "nebrandumas",
    "maksimalus": "minimumas",
    "išmatuojami": "neišmatuojamas",
    "psichinis": "fizinis",
    "gailestingas": "negailestingas",
    "negailestingas": "gailestingas",
    "kariuomenė": "civilinis",
    "protas": "pamiršk",
    "prisiminti": "pamiršk",
    "minimumas": "maksimalus",
    "mažuma": "dauguma",
    "klaidingas supratimas": "koncepcija",
    "praleisti": "nukentėti",
    "molinis": "molekulinė",
    "molekulinė": "molinis",
    "moralinis": "amoralus",
    "moralė": "amoralumas",
    "mirtingasis": "nemirtingas",
    "mirtingumas": "nemirtingumas",
    "padauginti": "atskirai",
    "keičiamas": "nekintamas",
    "nadir": "zenitas",
    "siaura": "išplėsti",
    "kylantis": "mirti",
    "neigiamas": "neutralus",
    "aplaidumas": "kruopštus",
    "sūnėnas": "dukterėčia",
    "neto": "bruto",
    "dukterėčia": "sūnėnas",
    "naktis": "diena",
    "naktinis": "dieną",
    "nominali": "tikras",
    "nerealu": "realus",
    "normalus": "nenormalus",
    "pastebėti": "ignoruoti",
    "skaitmeninis": "žodinis",
    "paklusnumas": "nepaklusnumas",
    "paklusnus": "nepaklusnus",
    "paklusk": "nepaklusti",
    "tikslas": "subjektyvus",
    "privalomas": "neprivaloma",
    "įstrižai": "statmenai",
    "nežinomybė": "pagarba",
    "neskaidrumas": "skaidrumas",
    "užimtas": "neužimta",
    "nusikaltimas": "gynyba",
    "agresyvus": "gynybinis",
    "pareigūnas": "neoficialus",
    "atvirumas": "artimas",
    "operatyvus": "neveikia",
    "priešinosi": "neprilygstama",
    "priešingas": "alternatyva",
    "optimizmas": "pesimizmas",
    "optimistas": "pesimistas",
    "neprivaloma": "privalomas",
    "žodžiu": "analinis",
    "įsakymas": "sutrikimas",
    "tvarkingai": "netvarkingai",
    "paprastas": "išgalvotas",
    "ekologiškas": "neorganinis",
    "organizuotas": "neorganizuotas",
    "ortodoksas": "netradicinis",
    "lauke": "patalpose",
    "neteisėta": "legalizuoti",
    "pervertinti": "nepakankamai įvertintas",
    "pridėtinės išlaidos": "paviršius",
    "atvira": "slaptas",
    "paketas": "išpakuoti",
    "skausmingas": "neskausminga",
    "neskausminga": "skausmingas",
    "lygiagrečiai": "įstrižai",
    "statmenai": "įstrižai",
    "dališkumas": "nešališkumas",
    "ypatumas": "bendrumas",
    "iš dalies": "visiškai",
    "praeiti": "bėgimas",
    "stovintis": "bėgimas",
    "praeitis": "ateitis",
    "pateikti": "nėra",
    "tėvelis": "motina",
    "kantrybė": "nekantrumas",
    "pacientas": "nekantrus",
    "globoja": "boikotuoti",
    "bausmė": "atlygis",
    "tobulumas": "netobulumas",
    "pralaidus": "nepralaidus",
    "leidžiama": "neleistinas",
    "leidžiamas": "prevencinis",
    "leidimas": "uždrausti",
    "asmeninis": "be asmenybės",
    "įtikinti": "atgrasyti",
    "pesimizmas": "optimizmas",
    "pesimistas": "optimistas",
    "fizinis": "psichinis",
    "ieškovas": "atsakovas",
    "malonu": "nepatinka",
    "daugiskaitos": "viengungis",
    "poliarinis": "ekvatorinis",
    "mandagus": "nepagarbus",
    "populiarus": "nepopuliarus",
    "poringumas": "tvirtumas",
    "galimybė": "neįmanoma",
    "posterior": "priekinis",
    "stiprus": "bejėgis",
    "potencialus": "faktinis",
    "skurdas": "turtas",
    "pagirti": "kritikuoti",
    "prieš tai": "pasisekė",
    "anksčiau": "sėkmingai",
    "prefiksas": "priesaga",
    "paruošimas": "rezoliucija",
    "paruošta": "nepasiruošęs",
    "norminis": "apibūdinantis",
    "buvimas": "nebuvimas",
    "konservuota": "sunaikinta",
    "prevencinis": "leidžiamas",
    "pirminis": "antrinis",
    "privatus": "visuomenė",
    "privačiai": "viešai",
    "tikėtinas": "neįtikėtinas",
    "produktyvus": "neproduktyvus",
    "apgaulingas": "šventas",
    "profesionalus": "mėgėjas",
    "progresas": "regresas",
    "laipsniškas": "regresyvus",
    "numatoma": "atgaline data",
    "saugoma": "neapsaugotas",
    "didžiuojasi": "kuklus",
    "įrodyti": "paneigti",
    "proksimalinis": "distalinis",
    "arti": "galutinis",
    "apdairus": "neprotingas",
    "visuomenė": "privatus",
    "viešai": "privačiai",
    "paskelbta": "nepaskelbtas",
    "traukti": "stumti",
    "punktualumas": "tardiness",
    "valyti": "reabilituoti",
    "grynumas": "priemaiša",
    "stumti": "traukti",
    "kvalifikuoti": "diskvalifikuoti",
    "karalienė": "karalius",
    "abejotinas": "neginčytinas",
    "greitai": "lėtai",
    "pakelti": "mažesnis",
    "racionalus": "neracionalus",
    "tikras": "nerealu",
    "realus": "nerealu",
    "nuraminti": "nerimauti",
    "prisiminti": "klausimas",
    "įrašyti": "ištrinti",
    "regresas": "progresas",
    "regresyvus": "laipsniškas",
    "reguliariai": "netaisyklingas",
    "reguliarumas": "pažeidimas",
    "reguliuojamas": "nereguliuojamas",
    "reabilituoti": "valyti",
    "atmetimas": "priėmimas",
    "atgaivinti": "amžius",
    "susijęs": "nesusijęs",
    "santykinis": "absoliutus",
    "aktualus": "nesvarbu",
    "patikimas": "nepatikimas",
    "religinis": "pasaulietinis",
    "atbaidymas": "pritraukimas",
    "gerbiamas": "nepriimtinas",
    "reputacija": "nuversti",
    "pasipriešinti": "pasidavimas",
    "rezoliucija": "paruošimas",
    "pagarbiai": "nepagarbus",
    "atsakingas": "neatsakingas",
    "suvaržytas": "neapsaugotas",
    "atgaline data": "numatoma",
    "gerbiamasis": "nepagarbus",
    "pasikeitimas": "patvirtinimas",
    "atlygis": "bausmė",
    "važiuoti": "vaikščioti",
    "prinokę": "žalias",
    "kyla": "kritimas",
    "rotorius": "statorius",
    "šiurkštumas": "lygumas",
    "apvalus": "kvadratas",
    "suapvalintas": "kampinis",
    "kaimas": "miesto",
    "skubėti": "laikytis",
    "deja": "laimingai",
    "liūdesys": "džiaugsmas",
    "nelaimė": "laimė",
    "saugus": "pavojingas",
    "saugumas": "nesaugumas",
    "vienodumas": "skirtumas",
    "sane": "psichiškas",
    "sanity": "beprotybė",
    "pasitenkinimas": "nepasitenkinimas",
    "pikantiškas": "nepatogu",
    "trūksta": "gausu",
    "mokslinis": "netikras",
    "antrinis": "pirminis",
    "pasaulietinis": "religinis",
    "atskyrimas": "sąjunga",
    "savanaudis": "nesavanaudiška",
    "parduoti": "pirkti",
    "vyresnysis": "jaunesnysis",
    "septinis": "antiseptikas",
    "paslauga": "kantrumas",
    "atsiskaityta": "nesuderinta",
    "aštrinti": "suplakti",
    "trumpas": "aukštas",
    "sutrumpinti": "pailginti",
    "šaukti": "šnabždesys",
    "rodyti": "paslėpti",
    "pusė": "apačioje",
    "viršuje": "apačioje",
    "reikšmė": "nereikšmingumas",
    "reikšmingas": "nereikšmingas",
    "panašus": "skirtingas",
    "paprasta": "junginys",
    "supaprastinti": "komplikuoja",
    "vienišas": "daugkartinis",
    "viengungis": "daugiskaitos",
    "nuskristi": "šaltinis",
    "sesuo": "brolis",
    "miegoti": "pabusti",
    "lėtai": "greitai",
    "mažas": "didelis",
    "lygumas": "šiurkštumas",
    "minkštumas": "ryškumas",
    "tvirtumas": "poringumas",
    "tirpus": "netirpi",
    "mokumas": "nemokumas",
    "tirpiklis": "nemokus",
    "sūnus": "dukra",
    "liūdnas": "džiaugsmingas",
    "pasakyta": "parašyta",
    "nerašytas": "parašyta",
    "atsitiktinis": "nuolatinis",
    "skleisti": "rinkti",
    "kvadratas": "apvalus",
    "stabilumas": "nestabilumas",
    "stabilus": "nestabilus",
    "stovėti": "derlius",
    "pradėti": "sustabdyti",
    "statorius": "rotorius",
    "likti": "judėti",
    "pastovus": "nestabili",
    "kietas": "švelnus",
    "staiga": "palaipsniui",
    "sterilus": "derlingas",
    "sustiprinti": "atlaisvinti",
    "švelnus": "kietas",
    "audringas": "ramus",
    "tiesiai": "išlenktas",
    "ištiesinti": "sulenkti",
    "svetimas": "pažintis",
    "jėga": "silpnumas",
    "ruožas": "susitraukti",
    "stipriai": "silpnai",
    "studija": "vieta",
    "kvailys": "žvalgyba",
    "subjektyvus": "tikslas",
    "pavaldus": "dominuojantis",
    "vėlesnis": "antecedentas",
    "esminis": "būdvardis",
    "atimti": "papildyti",
    "atimtis": "papildomai",
    "sėkmingai": "anksčiau",
    "sėkmė": "nesėkmė",
    "sėkmingas": "nesėkmingas",
    "pasiduoti": "išgyventi",
    "kenčia": "mėgautis",
    "pakankamumas": "nepakankamumas",
    "pakankamai": "nepakankamai",
    "priesaga": "prefiksas",
    "saulėtekis": "saulėlydis",
    "saulėlydis": "saulėtekis",
    "pranašesnis": "prastesnė",
    "tiekimas": "paklausa",
    "palaikoma": "nepatvirtintas",
    "paviršius": "pridėtinės išlaidos",
    "pasidavimas": "pasipriešinti",
    "išgyventi": "pasiduoti",
    "saldus": "rūgštus",
    "drėgnas": "sausas",
    "saldinti": "rūgštus",
    "simetrija": "asimetrija",
    "simpatiškas": "nesimpatėjantis",
    "sinergetinis": "antagonistinis",
    "sintezė": "analizė",
    "sintetinis": "analitinis",
    "tardiness": "punktualumas",
    "skoningas": "beskonis",
    "skanus": "beskonis",
    "beskonis": "skanus",
    "įtempta": "atsipalaidavęs",
    "terminalas": "tarpinis",
    "teizmas": "ateizmas",
    "teorinis": "empirinis",
    "ištroškęs": "alkanas",
    "sąmoningas": "neapgalvotas",
    "neapgalvotas": "sąmoningas",
    "taupus": "švaistomi",
    "banga": "atsipalaiduoti",
    "kaklaraištis": "atsitraukite",
    "bjaurus": "drąsus",
    "bailumas": "drąsa",
    "tolerancija": "netolerancija",
    "tolerantiškas": "netoleranti",
    "dantyta": "be dantų",
    "be dantų": "dantyta",
    "palietė": "nepaliestas",
    "tractable": "nesuderinamas",
    "tragedija": "komedija",
    "treniruotas": "nepatyrusi",
    "pasitikėjimas": "nepasitikėjimas",
    "tiesa": "neteisingumas",
    "bjaurumas": "grožis",
    "negraži": "grazus",
    "galutinis": "arti",
    "nepriimtina": "priimtinas",
    "nepripažintas": "pripažintas",
    "nepakitęs": "pakeista",
    "nedviprasmiškas": "dviprasmiškas",
    "neginklu": "ginkluotosios",
    "nesubalansuotas": "subalansuotas",
    "nesusijusi": "prijungtas",
    "nepažeistas": "sunaikintas",
    "netikrumas": "tikrumas",
    "nepakeičiama": "kintamas",
    "nepakeistas": "pasikeitė",
    "dėdė": "teta",
    "nepatvirtintas": "palaikoma",
    "sąmonės netekimas": "sąmonė",
    "nekonstitucinis": "konstitucinis",
    "netradicinis": "ortodoksas",
    "nenuosekli": "įsitikinęs",
    "atskleisti": "uždanga",
    "nesupjaustytas": "supjaustyti",
    "neapibrėžtas": "apibrėžta",
    "nepakankamai įvertintas": "pervertinti",
    "nepageidautinas": "pageidautina",
    "nepagrįstas": "vertas",
    "nebaigtas": "išsilavinę",
    "netikėtas": "tikimasi",
    "netikri": "ištikimas",
    "nepažįstamas": "pažįstamas",
    "nepalankus": "palankus",
    "atsiskleisti": "kartus",
    "nevykęs": "laimingas",
    "nelaimingas": "dorybingas",
    "nesveika": "sveikas",
    "nesvarbus": "svarbu",
    "nepagerintas": "patobulintas",
    "neinformuotas": "informuotas",
    "negyvenamas": "apgyvendintas",
    "nesuprantamas": "suprantama",
    "nenoras": "noras",
    "netyčia": "tyčia",
    "neįdomu": "įdomus",
    "sąjunga": "atskyrimas",
    "vienarūšis": "federalinė",
    "united": "padalintas",
    "negeras": "malonus",
    "neribotas": "ribotas",
    "nevedęs": "vedęs",
    "neužimta": "užimtas",
    "neoficialus": "pareigūnas",
    "neprilygstama": "priešinosi",
    "išpakuoti": "paketas",
    "nemalonus": "malonus",
    "nepopuliarus": "populiarus",
    "nepasiruošęs": "paruošta",
    "neproduktyvus": "produktyvus",
    "neapsaugotas": "suvaržytas",
    "nepaskelbtas": "paskelbta",
    "neginčytinas": "abejotinas",
    "nereguliuojamas": "reguliuojamas",
    "nesusijęs": "susijęs",
    "nepatikimas": "patikimas",
    "netikras": "mokslinis",
    "nesavanaudiška": "savanaudis",
    "nesuderinta": "atsiskaityta",
    "nestabilus": "stabilus",
    "nestabili": "pastovus",
    "nesėkmingas": "sėkmingas",
    "nesimpatėjantis": "simpatiškas",
    "atsitraukite": "kaklaraištis",
    "nepaliestas": "palietė",
    "nepatyrusi": "treniruotas",
    "neįprastas": "įprasta",
    "nenoriai": "noriai",
    "miesto": "kaimas",
    "įprasta": "neįprastas",
    "vertingas": "beverčiai",
    "uždanga": "atskleisti",
    "žodinis": "skaitmeninis",
    "pergalė": "nugalėti",
    "dorybingas": "nelaimingas",
    "matomumas": "nematomas",
    "matomas": "nematomas",
    "vokalas": "instrumental",
    "savanoriškas": "neprivalomas",
    "balsis": "konsonantas",
    "vaikščioti": "važiuoti",
    "nuslopinti": "vaškas",
    "karas": "ramybė",
    "atsargiai": "nepastebimas",
    "atliekos": "konservuoti",
    "švaistomi": "taupus",
    "vaškas": "nuslopinti",
    "silpnai": "stipriai",
    "silpnumas": "jėga",
    "turtas": "skurdas",
    "nesvarus": "svargi",
    "svargi": "nesvarus",
    "šnabždesys": "šaukti",
    "balta": "juoda",
    "visiškai": "iš dalies",
    "platus": "siaura",
    "noriai": "nenoriai",
    "noras": "nenoras",
    "vėjas": "atsipalaiduoti",
    "išmintis": "kvailystė",
    "protingas": "kvaila",
    "nerimauti": "nuraminti",
    "vertas": "nepagrįstas",
    "parašyta": "nerašytas",
    "jaunas": "amžiaus",
    "zenitas": "nadir",
}
